@@ -26,7 +26,7 @@ import subprocess
 import sys
 from typing import IO, TYPE_CHECKING, Any, List
 
-from cobib.config import config
+from cobib.config import Event, config
 from cobib.database import Database
 from cobib.utils.rel_path import RelPath
 
@@ -66,7 +66,6 @@ class UndoCommand(Command):
                 "You must enable coBib's git-tracking in order to use the `Undo` command."
                 "\nPlease refer to the man-page for more information on how to do so."
             )
-            print(msg, file=sys.stderr)
             LOGGER.error(msg)
             return
 
@@ -77,7 +76,6 @@ class UndoCommand(Command):
                 "You have configured, but not initialized coBib's git-tracking."
                 "\nPlease consult `cobib init --help` for more information on how to do so."
             )
-            print(msg, file=sys.stderr)
             LOGGER.error(msg)
             return
 
@@ -91,9 +89,10 @@ class UndoCommand(Command):
             largs = parser.parse_args(args)
         except argparse.ArgumentError as exc:
             LOGGER.error(exc.message)
-            print(exc.message, file=sys.stderr)
             return
 
+        Event.PreUndoCommand.fire(largs)
+
         LOGGER.debug("Obtaining git log.")
         lines = subprocess.check_output(
             [
@@ -143,10 +142,11 @@ class UndoCommand(Command):
                 break
         else:
             msg = "Could not find a commit to undo. Please commit something first!"
-            print(msg, file=sys.stderr)
             LOGGER.warning(msg)
             sys.exit(1)
 
+        Event.PostUndoCommand.fire(root, sha)
+
     @staticmethod
     def tui(tui: cobib.tui.TUI) -> None:
         # pdoc will inherit the docstring from the base class
