@@ -13,6 +13,7 @@ import io
 import logging
 import os
 import sys
+from enum import Enum
 from pathlib import Path
 from typing import Any, Dict, Optional, TextIO, Union
 
@@ -32,6 +33,14 @@ ANSI_COLORS = [
 ]
 
 
+class LabelSuffix(Enum):
+    """Suffixes to disambiguate Entry labels."""
+
+    ALPHA = lambda count: chr(96 + count)
+    CAPTIAL = lambda count: chr(64 + count)
+    NUMERIC = lambda count: str(count)  # pylint: disable=unnecessary-lambda
+
+
 class Config(Dict[str, Any]):
     """coBib's configuration class.
 
@@ -54,6 +63,7 @@ class Config(Dict[str, Any]):
     DEFAULTS: Dict[str, Any] = {
         "logging": {
             "logfile": "~/.cache/cobib/cobib.log",
+            "version": "~/.cache/cobib/version",
         },
         "commands": {
             "edit": {
@@ -72,6 +82,8 @@ class Config(Dict[str, Any]):
         "database": {
             "file": "~/.local/share/cobib/literature.yaml",
             "format": {
+                "label_default": "{label}",
+                "label_suffix": ("_", LabelSuffix.ALPHA),
                 "suppress_latex_warnings": True,
             },
             "git": False,
@@ -83,6 +95,7 @@ class Config(Dict[str, Any]):
                 },
             },
         },
+        "events": {},
         "parsers": {
             "bibtex": {
                 "ignore_non_standard_types": False,
@@ -188,7 +201,7 @@ class Config(Dict[str, Any]):
     MARKER = object()
     """A helper object for detecting the nested recursion-threshold."""
 
-    EXCEPTIONAL_KEYS = {"url_map"}
+    EXCEPTIONAL_KEYS = {"events", "url_map"}
     """A set of exceptional keys which do not cause automatic item creation. This is required in
     order to support `dict`-like configuration options properly."""
 
@@ -397,6 +410,10 @@ class Config(Dict[str, Any]):
         self._assert(
             isinstance(self.logging.logfile, str), "config.logging.logfile should be a string."
         )
+        self._assert(
+            self.logging.version is None or isinstance(self.logging.version, str),
+            "config.logging.version should be a string or `None`.",
+        )
 
         # COMMANDS section
         LOGGER.debug("Validating the COMMANDS configuration section.")
@@ -446,6 +463,23 @@ class Config(Dict[str, Any]):
                 "format for which most citation styles include macros. See also "
                 "https://www.bibtex.com/f/month-field/"
             )
+        self._assert(
+            isinstance(self.database.format.label_default, str),
+            "config.database.format.label_default should be a string.",
+        )
+        self._assert(
+            isinstance(self.database.format.label_suffix, tuple)
+            and len(self.database.format.label_suffix) == 2,
+            "config.database.format.label_suffix should be a tuple of length 2.",
+        )
+        self._assert(
+            isinstance(self.database.format.label_suffix[0], str),
+            "The first entry of config.database.format.label_suffix should be a string.",
+        )
+        self._assert(
+            callable(self.database.format.label_suffix[1]),
+            "The first entry of config.database.format.label_suffix should be a function.",
+        )
         self._assert(
             isinstance(self.database.format.suppress_latex_warnings, bool),
             "config.database.format.suppress_latex_warnings should be a boolean.",
@@ -463,6 +497,14 @@ class Config(Dict[str, Any]):
             "config.database.stringify.list_separator.url should be a string.",
         )
 
+        # EVENTS section
+        self._assert(isinstance(self.events, dict), "config.events should be a dict.")
+        for event in self.events:
+            self._assert(
+                event.validate(),
+                f"config.events.{event} did not pass its validation check.",
+            )
+
         # PARSER section
         self._assert(
             isinstance(self.parsers.bibtex.ignore_non_standard_types, bool),
@@ -489,8 +531,7 @@ class Config(Dict[str, Any]):
 
         # TUI.COLORS section
         LOGGER.debug("Validating the TUI.COLORS configuration section.")
-        # pylint: disable=consider-iterating-dictionary
-        for name in self.DEFAULTS["tui"]["colors"].keys():
+        for name in self.DEFAULTS["tui"]["colors"]:
             self._assert(
                 name in self.tui.colors.keys(), f"Missing config.tui.colors.{name} specification!"
             )
@@ -511,8 +552,7 @@ class Config(Dict[str, Any]):
 
         # TUI.KEY_BINDINGS section
         LOGGER.debug("Validating the TUI.KEY_BINDINGS configuration section.")
-        # pylint: disable=consider-iterating-dictionary
-        for command in self.DEFAULTS["tui"]["key_bindings"].keys():
+        for command in self.DEFAULTS["tui"]["key_bindings"]:
             self._assert(
                 command in self.tui.key_bindings.keys(),
                 f"Missing config.tui.key_bindings.{command} key binding!",
@@ -564,8 +604,12 @@ class Config(Dict[str, Any]):
 
     def defaults(self) -> None:
         """Resets the configuration to the default settings."""
-        # pylint: disable=consider-using-dict-items,consider-iterating-dictionary
-        for section in self.DEFAULTS.keys():
+        # pylint: disable=consider-using-dict-items
+        for section in self.DEFAULTS:
+            if section == "events":
+                # manually reset events
+                self["events"] = {}
+                continue
             self[section].update(**self.DEFAULTS[section])
 
     def get_ansi_color(self, name: str) -> str:
