@@ -2,13 +2,14 @@
 
 import tempfile
 from os import remove
-from typing import Any
+from typing import Any, Optional, Tuple
 
 import pytest
 import requests
 
-from cobib.config import config
+from cobib.config import Event, config
 from cobib.utils.file_downloader import FileDownloader
+from cobib.utils.rel_path import RelPath
 
 from .. import get_resource
 
@@ -70,8 +71,8 @@ def test_download(monkeypatch: pytest.MonkeyPatch) -> None:
         )
         if path is None:
             pytest.skip("Likely, a requests error occured.")
-        with open(get_resource("__init__.py", "utils"), "r") as expected:
-            with open(tmpdirname + "/dummy.pdf", "r") as truth:
+        with open(get_resource("__init__.py", "utils"), "r", encoding="utf-8") as expected:
+            with open(tmpdirname + "/dummy.pdf", "r", encoding="utf-8") as truth:
                 assert expected.read() == truth.read()
 
 
@@ -101,18 +102,23 @@ def test_skip_download_if_no_pdf(setup_remove_content_length: Any) -> None:
         )
 
 
-def test_skip_download_if_exists(caplog: pytest.LogCaptureFixture) -> None:
+@pytest.mark.parametrize("overwrite", [False, True])
+def test_skip_download_if_exists(caplog: pytest.LogCaptureFixture, overwrite: bool) -> None:
     """Test that download is skipped when file already exists.
 
     Args:
         caplog: the built-in pytest fixture.
+        overwrite: whether or not to overwrite the existing file.
     """
     with tempfile.TemporaryDirectory() as tmpdirname:
-        open(tmpdirname + "/dummy.pdf", "w").close()  # pylint: disable=consider-using-with
+        open(  # pylint: disable=consider-using-with
+            tmpdirname + "/dummy.pdf", "w", encoding="utf-8"
+        ).close()
         FileDownloader().download(
             "https://gitlab.com/mrossinek/cobib/-/raw/master/tests/utils/__init__.py",
             "dummy",
-            tmpdirname,
+            folder=tmpdirname,
+            overwrite=overwrite,
         )
         for mod, lvl, msg in caplog.record_tuples:
             if (
@@ -122,7 +128,9 @@ def test_skip_download_if_exists(caplog: pytest.LogCaptureFixture) -> None:
             ):
                 break
         else:
-            assert False, "Download not aborted."
+            assert overwrite, "This statement should only be reached when overwrite is enabled!"
+            return
+        assert not overwrite, "This statement should only be reached when overwrite is disabled!"
 
 
 @pytest.mark.parametrize(
@@ -187,3 +195,72 @@ def test_gracefully_fail_download(monkeypatch: pytest.MonkeyPatch) -> None:
             )
             is None
         )
+
+
+def test_event_pre_download(monkeypatch: pytest.MonkeyPatch) -> None:
+    """Test the PreFileDownload event.
+
+    Args:
+        monkeypatch: the built-in pytest fixture.
+    """
+
+    @Event.PreFileDownload.subscribe
+    def hook(
+        url: str, label: str, folder: Optional[str]
+    ) -> Optional[Tuple[str, str, Optional[str]]]:
+        label = "test"
+        return (url, label, folder)
+
+    assert Event.PreFileDownload.validate()
+
+    with tempfile.TemporaryDirectory() as tmpdirname:
+        try:
+            # ensure file does not exist yet
+            remove(tmpdirname + "/test.pdf")
+        except FileNotFoundError:
+            pass
+        # disable the PDF assertion method
+        monkeypatch.setattr(FileDownloader, "_assert_pdf", lambda _: True)
+        path = FileDownloader().download(
+            "https://gitlab.com/mrossinek/cobib/-/raw/master/tests/utils/__init__.py",
+            "dummy",
+            tmpdirname,
+        )
+        if path is None:
+            pytest.skip("Likely, a requests error occured.")
+        with open(get_resource("__init__.py", "utils"), "r", encoding="utf-8") as expected:
+            with open(tmpdirname + "/test.pdf", "r", encoding="utf-8") as truth:
+                assert expected.read() == truth.read()
+
+
+def test_event_post_download(monkeypatch: pytest.MonkeyPatch) -> None:
+    """Test the PostFileDownload event.
+
+    Args:
+        monkeypatch: the built-in pytest fixture.
+    """
+
+    @Event.PostFileDownload.subscribe
+    def hook(path: RelPath) -> Optional[RelPath]:  # type: ignore[return]
+        path.path.rename(path.path.parent / "test.pdf")
+
+    assert Event.PostFileDownload.validate()
+
+    with tempfile.TemporaryDirectory() as tmpdirname:
+        try:
+            # ensure file does not exist yet
+            remove(tmpdirname + "/test.pdf")
+        except FileNotFoundError:
+            pass
+        # disable the PDF assertion method
+        monkeypatch.setattr(FileDownloader, "_assert_pdf", lambda _: True)
+        path = FileDownloader().download(
+            "https://gitlab.com/mrossinek/cobib/-/raw/master/tests/utils/__init__.py",
+            "dummy",
+            tmpdirname,
+        )
+        if path is None:
+            pytest.skip("Likely, a requests error occured.")
+        with open(get_resource("__init__.py", "utils"), "r", encoding="utf-8") as expected:
+            with open(tmpdirname + "/test.pdf", "r", encoding="utf-8") as truth:
+                assert expected.read() == truth.read()
